@@ -25,7 +25,7 @@ predict_mxmodel_mixture <- function(object, newdata = NULL, ...){
     }
     mod_fix$data$observed <- rbind(newdata, mod_fix$data$observed)
     mod_fix@matrices$weights$free[,] <- FALSE
-    mod_fix <- mxRun(mod_fix)
+    mod_fix <- OpenMx::mxRun(mod_fix)
     return(class_prob(mod_fix, "individual")[[1]][1:nrow(newdata), , drop = FALSE])
   }
 }
